.. SFChat documentation master file, created by
   sphinx-quickstart on Thu May 28 19:06:34 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

##################################
Welcome to SFChat's documentation!
##################################
Contents:

.. toctree::
   :maxdepth: 4
   :titlesonly:

   Objective
   Mockups
   Technology
   Installation
   Protocol/index
   REST API/index
   Diagrams
   Database
   MongoDB workflow/index
   Django configuration
   FrontEnd
   Google Analytics
   Task queue
   Administration panel
   Glossary
   

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
